nvector.objects.FrameB — nvector 0.7.5 documentation

# nvector.objects.FrameB

class `FrameB`(position, yaw=0, pitch=0, roll=0, degrees=False)

  > Body frame

  Parameters
    position: ECEFvector, GeoPoint or Nvector object

      > position of the vehicle’s reference point which also coincides with the origin of the frame B.

      yaw, pitch, roll: real scalars

        defining the orientation of frame B in [deg] or [rad].

      degreesbool

        if True yaw, pitch, roll are given in degrees otherwise in radians

  Notes

  The frame is fixed to the vehicle where the x-axis points forward, the y-axis to the right (starboard) and the z-axis in the vehicle’s down direction.

  `__init__`(self, position, yaw=0, pitch=0, roll=0, degrees=False)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `Pvector`(self, pvector) | Returns Pvector relative to the local frame.
  `__init__`(self, position[, yaw, pitch, roll, …]) | Initialize self.

  Attributes

  `R_EN` | Rotation matrix to go between E and B frame